@@ -11,10 +11,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.207-5-gcad7a51
+# git description: v4.208-1-gf69e9f5
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.208';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.209';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
@@ -330,7 +330,7 @@ sub configure {
       }
     ],
     [ GithubMeta => { ':version' => '0.10' } ],
-    [ ContributorsFromGit => { ':version' => '0.005' } ],
+    [ 'Git::Contributors' ],
   ) if $self->open_source;
 
   $self->add_plugins('AutoPrereqs')
@@ -521,9 +521,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Randy Stauner ACKNOWLEDGEMENTS RWSTAUNER's PluginBundle Romanov Sergey cpan
-testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto
-metadata placeholders metacpan
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS RWSTAUNER's PluginBundle cpan testmatrix url
+annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
+placeholders metacpan
 
 =head1 NAME
 
@@ -531,7 +531,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.208
+version 4.209
 
 =head1 SYNOPSIS
 
@@ -678,9 +678,7 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   [GithubMeta]
   :version = 0.10
 
-  [ContributorsFromGit]
-  :version = 0.005
-
+  [Git::Contributors]
   [AutoPrereqs]
 
   [MetaNoIndex]
@@ -814,12 +812,22 @@ L<https://github.com/rwstauner/Dist-Zilla-PluginBundle-Author-RWSTAUNER>
 
 Randy Stauner <rwstauner@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Sergey Romanov
+=for stopwords Karen Etheridge Sergey Romanov
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
 
 Sergey Romanov <complefor@rambler.ru>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Randy Stauner.
